as_inits: Return the current state of a 'JointAI' model as list to be...

View source: R/lme_imp_adaptive.R View source: R/JM_imp_adaptive.R

as_initsR Documentation

Return the current state of a 'JointAI' model as list to be used as initial values

Description

Return the current state of a 'JointAI' model as list to be used as initial values

Return the current state of a 'JointAI' model as list to be used as initial values

Usage

as_inits(object, what = c("RinvD", "invD", "tau", "b"))

as_inits(object, what = c("RinvD", "invD", "tau", "b"))

Arguments

object

an object of class 'JointAI'

what

vector of node types


NErler/simvalidator documentation built on May 17, 2022, 7:54 a.m.