delete_MAR: Create MAR missingness

View source: R/delete_MAR.R

delete_MARR Documentation

Create MAR missingness

Description

Create MAR missingness

Usage

delete_MAR(
  data,
  missing,
  idvars = NULL,
  varlvls = NULL,
  groups = NULL,
  seed = NULL
)

Arguments

data

a data.frame

missing

a named vector giving the names of covariates and proportion of values to be deleted

idvars

optional vector with names of ID variables that should be used to identify levels in a multi-level setting

varlvls

named vector giving the level of each variable

groups

list with grouping information


NErler/simvalidator documentation built on May 17, 2022, 7:54 a.m.