delete_MCAR: Create MCAR missingness

View source: R/delete_MCAR.R

delete_MCARR Documentation

Create MCAR missingness

Description

Create MCAR missingness

Usage

delete_MCAR(
  data,
  missing,
  idvars = NULL,
  varlvls = NULL,
  groups = NULL,
  mis_seed = NULL
)

Arguments

data

a data.frame

missing

a named vector giving the names of covariates and proportion of values to be deleted

idvars

optional vector with names of ID variables that should be used to identify levels in a multi-level setting

varlvls

named vector giving the level of each variable

groups

list with grouping information

mis_seed

optional seed value


NErler/simvalidator documentation built on May 17, 2022, 7:54 a.m.