extract_covar_pars: Extract parameters necessary to simulate covariate data from...

View source: R/extract_from_JointAI.R

extract_covar_parsR Documentation

Extract parameters necessary to simulate covariate data from an object of class 'JointAI'

Description

Extract parameters necessary to simulate covariate data from an object of class 'JointAI'

Usage

extract_covar_pars(object, timevar = NULL)

Arguments

object

object of class 'JointAI'

timevar

name of the time variable, is there is one


NErler/simvalidator documentation built on May 17, 2022, 7:54 a.m.