extract_outcome_pars: Extract parameters necessary to simulate an outome from an...

View source: R/extract_from_JointAI.R

extract_outcome_parsR Documentation

Extract parameters necessary to simulate an outome from an object of class 'JointAI'

Description

This function obtains the response_type (from the analysis_type), formula, reg_coefs (extract_reg_coefs()), types (extract_types()), baseline hazard coefficients and knots (extract_basehaz() and extract_basehaz_knots()), mean censoring time (extract_mean_cens()), upper limit of where to search for the event time (.up) and the step size with which to increase that upper limit (up_step).

Usage

extract_outcome_pars(object)

Arguments

object

object of class 'JointAI'


NErler/simvalidator documentation built on May 17, 2022, 7:54 a.m.