extract_rd_vcov: Extract the posterior mean of the random effects...

View source: R/extract_from_JointAI.R

extract_rd_vcovR Documentation

Extract the posterior mean of the random effects variance-covariance matrices from an object of class 'JointAI'

Description

Extract the posterior mean of the random effects variance-covariance matrices from an object of class 'JointAI'

Usage

extract_rd_vcov(object)

Arguments

object

object of class 'JointAI'


NErler/simvalidator documentation built on May 17, 2022, 7:54 a.m.