get_result_default: Extract a summary of the model results from a standard model...

get_result_defaultR Documentation

Extract a summary of the model results from a standard model This function uses coef() and confint().

Description

Extract a summary of the model results from a standard model This function uses coef() and confint().

Usage

get_result_default(fitted_model, type = NA, seed = NA, scen = NA, ...)

Arguments

fitted_model

a fitted model object

type

optional character string specifying the type (to identify what type of model the results belong to later in the visualization and description of results)

seed

optional (but) suggested seed value. Will be used when called from within run_models().

scen

optional name of scenario

...

optional additional arguments for compatibility with other get_result_<...> functions


NErler/simvalidator documentation built on May 17, 2022, 7:54 a.m.