View source: R/lme_imp_adaptive.R View source: R/JM_imp_adaptive.R
| as_inits | R Documentation |
Return the current state of a 'JointAI' model as list to be used as initial values
Return the current state of a 'JointAI' model as list to be used as initial values
as_inits(object, what = c("RinvD", "invD", "tau", "b"))
as_inits(object, what = c("RinvD", "invD", "tau", "b"))
object |
an object of class 'JointAI' |
what |
vector of node types |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.