| delete_MAR | R Documentation |
Create MAR missingness
delete_MAR( data, missing, idvars = NULL, varlvls = NULL, groups = NULL, seed = NULL )
data |
a |
missing |
a named vector giving the names of covariates and proportion of values to be deleted |
idvars |
optional vector with names of ID variables that should be used to identify levels in a multi-level setting |
varlvls |
named vector giving the level of each variable |
groups |
list with grouping information |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.