View source: R/extract_from_JointAI.R
| extract_covar_pars | R Documentation |
Extract parameters necessary to simulate covariate data from an object of class 'JointAI'
extract_covar_pars(object, timevar = NULL)
object |
object of class 'JointAI' |
timevar |
name of the time variable, is there is one |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.