View source: R/extract_from_JointAI.R
| extract_outcome_pars | R Documentation |
This function obtains the response_type (from the analysis_type),
formula, reg_coefs (extract_reg_coefs()), types (extract_types()),
baseline hazard coefficients and knots (extract_basehaz() and
extract_basehaz_knots()), mean censoring time (extract_mean_cens()),
upper limit of where to search for the event time (.up) and the step
size with which to increase that upper limit (up_step).
extract_outcome_pars(object)
object |
object of class 'JointAI' |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.