| get_result_default | R Documentation |
coef() and confint().Extract a summary of the model results from a standard model
This function uses coef() and confint().
get_result_default(fitted_model, type = NA, seed = NA, scen = NA, ...)
fitted_model |
a fitted model object |
type |
optional character string specifying the type (to identify what type of model the results belong to later in the visualization and description of results) |
seed |
optional (but) suggested seed value. Will be used when called
from within |
scen |
optional name of scenario |
... |
optional additional arguments for compatibility with other
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.